// Generated by dts-bundle v0.7.3

export const ROOT_URL: string;
export const ENDPOINTS: Record<string, Endpoint>;
export const MAX_FILE_SIZE = 5500000;

type ExpressUtilsOptions = {
        serverKey: string;
        clientKey: string;
};
export type FileType = string | Blob | File | Buffer;
/**
    * A class for interacting with the PDF.js Express REST APIs
    */
class ExpressUtils {
        /**
            * Initialize the class
            * @param {Object} options
            * @param {string} options.serverKey Your server side license key. Can be fetched from your profile at https://pdfjs.express
            * @param {string} options.clientKey Your client side license key. Can be fetched from your profile at https://pdfjs.express
            * @example
            * import ExpressUtils from '@pdftron/pdfjs-express-utils'
            *
            * const util = new ExpressUtils({
            *  serverKey: 'my_server_key',
            *  clientKey: 'my_client_key'
            * })
            */
        constructor({ serverKey, clientKey }: ExpressUtilsOptions);
        /**
            * Sets the file to process. Throws if the file is in memory and is too big (5.5 MB max).
            * @param {string|Blob|File|Buffer} file The file to process. Type must be 'string' (url) if the file is over 5.5mb
            * @returns {ExpressRESTUtil} Returns current instance for function chaining
            */
        setFile(file: FileType): this;
        /**
            * Sets the XFDF to process. Throws if XFDF is empty or not a string
            * @param {string} xfdf The XFDF to use in the conversion
            * @returns {ExpressRESTUtil} Returns current instance for function chaining
            */
        setXFDF(xfdf: string): this;
        /**
            * Calls the PDF.js Express API to merge the current file and XFDF together.
            * @returns {Promise<Response>} Resolves to a Response object
            * @example
            * const instance = new ExpressUtils({ serverKey: '', clientKey: '' });
            * instance.setFile(myFile)
            * instance.setXFDF(xfdfString)
            * const resp = await instance.merge();
            *
            * const url = resp.url; // the URL of the new file
            * const key = resp.key; // The key used to fetch the file
            *
            * const blob = await resp.getBlob(); // downloads the 'url' and returns a blob
            */
        merge(): Promise<Response>;
        /**
            * Calls the PDF.js Express API to set the XFDF of a document. This will overwrite any existing annotations/xfdf the document may have.
            * @returns {Promise<Response>} Resolves to a Response object
            * @example
            * const instance = new ExpressUtils({ serverKey: '', clientKey: '' });
            * instance.setFile(myFile)
            * instance.setXFDF(xfdfString)
            * const resp = await instance.set();
            *
            * const url = resp.url; // the URL of the new file
            * const key = resp.key; // The key used to fetch the file
            *
            * const blob = await resp.getBlob(); // downloads the 'url' and returns a blob
            */
        set(): Promise<Response>;
        /**
            * Calls the PDF.js Express to extract the xfdf from a document
            * @returns {Promise<Response>} Resolves to a Response object. You can access the xfdf with `response.xfdf`
            * @example
            * const instance = new ExpressUtils({ serverKey: '', clientKey: '' });
            * instance.setFile(myFile)
            * const resp = await instance.extract();
            * const xfdfString = resp.xfdf;
            */
        extract(): Promise<Response>;
}
export default ExpressUtils;

export default ExpressUtils;

class RequestBuilder {
    setFile(file: FileType): this;
    setXFDF(xfdf: string): this;
    setLicense(license: string): this;
    setEndpoint(endpoint: Endpoint): this;
    make(): Promise<Response>;
}
export default RequestBuilder;

/**
    * A class representing the response from the Express REST API.
    * Contains utility methods for working with files.
    * Should not be directly instantiated, and should be returned the main SDK APIs.
    *
    * @property {string} url The URL used for downloading the document
    * @property {string} id The ID of the document
    * @property {string} key The authentication key used to download the file. Get requests to 'url` must contain a `Authorization: {key}` header
    * @property {string} [xfdf] The xfdf for the document
    */
type ResponseOptions = {
        url: string;
        id: string;
        key: string;
        license: string;
        xfdf: string;
};
export class Response {
        url?: string;
        id?: string;
        key?: string;
        xfdf?: string;
        constructor({ url, id, key, license, xfdf }: ResponseOptions);
        /**
            * Fetches and returns the file as a Blob
            * @returns {Promise<Blob>}
            */
        getBlob(): Promise<Blob>;
        /**
            * Deletes the file from the server and destroys the instance.
            * If delete is not called, the file will still becoming inaccessible after 3 hours,
            * and will be permanently deleted after ~24 hours.
            *
            * Deleting a file does not count as a transaction
            * @returns {Promise<void>}
            * @example
            * const instance = new APIUtils({ serverKey: '', clientKey: '' });
            * instance.setFile(myFile)
            * instance.setXFDF(xfdfString)
            * const resp = await instance.set();
            * const blob = await resp.getBlob(); // get the blob for your apps usage
            * await resp.deleteFile(); // delete the file
            */
        deleteFile(): Promise<void>;
}
export {};

export type Endpoint = {
    url: string;
    method: string;
};

export const isClient: boolean;
export const isServer: boolean;
export const env: any;

export const throwFileTooLargeError: () => never;
export const throwInvalidFileTypeError: () => never;
export const throwInvalidXFDFError: () => never;
export const throwMissingDataError: (funcName: string, required: string[]) => never;
export const throwInvalidRequestError: (funcName: string, reason: string) => never;

